gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[taler-anastasis] 09/13: created policy trait


From: gnunet
Subject: [taler-anastasis] 09/13: created policy trait
Date: Sun, 03 May 2020 18:02:33 +0200

This is an automated email from the git hooks/post-receive script.

dennis-neufeld pushed a commit to branch master
in repository anastasis.

commit 005023638918f00097f1a17bc1cc5adffdfa1bfb
Author: Dennis Neufeld <address@hidden>
AuthorDate: Sat May 2 08:43:24 2020 +0000

    created policy trait
---
 ...esting_trait_truth.c => testing_trait_policy.c} | 40 +++++++++++-----------
 src/lib/testing_trait_truth.c                      |  6 ++--
 2 files changed, 23 insertions(+), 23 deletions(-)

diff --git a/src/lib/testing_trait_truth.c b/src/lib/testing_trait_truth.c
index 1088484..51696e1 100644
--- a/src/lib/testing_trait_truth.c
+++ b/src/lib/testing_trait_truth.c
@@ -17,8 +17,8 @@
   <http://www.gnu.org/licenses/>
 */
 /**
- * @file lib/testing_api_trait_uuid.c
- * @brief traits to offer a hash
+ * @file lib/testing_trait_truth.c
+ * @brief traits to offer a truth
  * @author Christian Grothoff
  * @author Dominik Meister
  * @author Dennis Neufeld
@@ -50,7 +50,7 @@ ANASTASIS_TESTING_get_trait_truth (const struct 
TALER_TESTING_Command *cmd,
 
 
 /**
- * Offer an truth.
+ * Offer a truth.
  *
  * @param index the truth's index number.
  * @param t the truth to offer.

diff --git a/src/lib/testing_trait_truth.c b/src/lib/testing_trait_policy.c
similarity index 56%
copy from src/lib/testing_trait_truth.c
copy to src/lib/testing_trait_policy.c
index 1088484..45e773c 100644
--- a/src/lib/testing_trait_truth.c
+++ b/src/lib/testing_trait_policy.c
@@ -17,8 +17,8 @@
   <http://www.gnu.org/licenses/>
 */
 /**
  * @file lib/testing_api_trait_uuid.c
  * @brief traits to offer a hash
  * @author Christian Grothoff
  * @author Dominik Meister
  * @author Dennis Neufeld
@@ -26,48 +26,48 @@
 #include "platform.h"
 #include "anastasis_testing_lib.h"
 
-#define ANASTASIS_TESTING_TRAIT_TRUTH "anastasis-truth"
+#define ANASTASIS_TESTING_TRAIT_POLICY "anastasis-policy"
 
 
 /**
  * Obtain a truth from @a cmd.
  *
  * @param cmd command to extract the truth from.
  * @param index the index of the truth
  * @param t[out] set to the truth coming from @a cmd.
  * @return #GNUNET_OK on success.
  */
 int
-ANASTASIS_TESTING_get_trait_truth (const struct TALER_TESTING_Command *cmd,
-                                   unsigned int index,
-                                   const struct ANASTASIS_Truth **t)
+ANASTASIS_TESTING_get_trait_policy (const struct TALER_TESTING_Command *cmd,
+                                    unsigned int index,
+                                    const struct ANASTASIS_Policy **p)
 {
   return cmd->traits (cmd->cls,
-                      (const void **) t,
-                      ANASTASIS_TESTING_TRAIT_TRUTH,
+                      (const void **) p,
+                      ANASTASIS_TESTING_TRAIT_POLICY,
                       index);
 }
 
 
 /**
- * Offer an truth.
+ * Offer a policy.
  *
  * @param index the truth's index number.
  * @param t the truth to offer.
  * @return #GNUNET_OK on success.
  */
 struct TALER_TESTING_Trait
-ANASTASIS_TESTING_make_trait_truth
+ANASTASIS_TESTING_make_trait_policy
   (unsigned int index,
-  const struct ANASTASIS_Truth *t)
+  const struct ANASTASIS_Policy *p)
 {
   struct TALER_TESTING_Trait ret = {
     .index = index,
-    .trait_name = ANASTASIS_TESTING_TRAIT_TRUTH,
-    .ptr = (const void *) t
+    .trait_name = ANASTASIS_TESTING_TRAIT_POLICY,
+    .ptr = (const void *) p
   };
   return ret;
 }
 
 
-/* end of testing_trait_truth.c */
+/* end of testing_trait_policy.c */
@@ -17,8 +17,8 @@
 */
 /**
- * @file lib/testing_api_trait_uuid.c
- * @brief traits to offer a hash
+ * @file lib/testing_trait_policy.c
+ * @brief traits to offer a policy
  * @author Christian Grothoff
  * @author Dominik Meister
@@ -26,48 +26,48 @@
 
 /**
- * Obtain a truth from @a cmd.
+ * Obtain a policy from @a cmd.
  *
@@ -26,48 +26,48 @@
  *
- * @param cmd command to extract the truth from.
- * @param index the index of the truth
- * @param t[out] set to the truth coming from @a cmd.
+ * @param cmd command to extract the policy from.
+ * @param index the index of the policy
+ * @param t[out] set to the policy coming from @a cmd.
  * @return #GNUNET_OK on success.
  */
@@ -26,48 +26,48 @@
  *
- * @param index the truth's index number.
- * @param t the truth to offer.
+ * @param index the policy's index number.
+ * @param t the policy to offer.
  * @return #GNUNET_OK on success.
  */
-- 
To stop receiving notification emails like this one, please contact
address@hidden.



reply via email to

[Prev in Thread] Current Thread [Next in Thread]